pycocoa.tables

Package pycocoa :: Module tables |
[frames] | no frames]

# Module tables

Types Table and TableWindow, wrapping ObjC `NSTableView`, `NSWindow`.

Version: 25.04.03

Classes
| Table Python rows and columns {Table} Type, wrapping an ObjC `NSTableView`.
| TableWindow Python Type for a vertically scrollable window, wrapping ObjC `NSWindow/NSScrollView`.

Functions
closeTables() Close all tables. |

Variables
| __all__ = `_ALL_LAZY.tables`
| NSTableViewDelegate = `<ObjCDelegate(_NSTableViewDelegate of 0x`...``

Variables Details

  ### NSTableViewDelegate Value:
      <ObjCDelegate(_NSTableViewDelegate of 0x600000262bb0) at 0x7fe82017cb9
      0>